@@ -15,6 +15,7 @@
 ##' maximization,
 ##' @param envir an optional environment specifying where to get intermediate
 ##' values calculated in \code{\link{EI}}.
+##' @param proxy an optional Boolean, if TRUE EI is replaced by the kriging mean (to minimize)
 ##' @return The gradient of the expected improvement criterion with respect to
 ##' x.  Returns 0 at design points (where the gradient does not exist).
 ##' @author David Ginsbourger 
@@ -93,8 +94,8 @@
 ##' }
 ##' 
 ##' @export EI.grad
-EI.grad <- function(x, model, plugin=NULL, type="UK", minimization = TRUE, envir=NULL){ 
-	
+EI.grad <- function(x, model, plugin=NULL, type="UK", minimization = TRUE, envir=NULL, proxy=FALSE){ 
+
   ########################################################################################
   if (is.null(plugin)){ 
     if (minimization) {
@@ -124,25 +125,25 @@ EI.grad <- function(x, model, plugin=NULL, type="UK", minimization = TRUE, envir
   if (is.null(envir))
   {  
     predx <- predict(object=model, newdata=newdata, type=type, checkNames = FALSE,se.compute=TRUE,cov.compute=FALSE)
-     kriging.mean <- predx$mean
-     if(!minimization) kriging.mean <- -kriging.mean
-     kriging.sd <- predx$sd
-     v <- predx$Tinv.c
-     c <- predx$c
-  
-     xcr <- (m - kriging.mean)/kriging.sd
-     xcr.prob <- pnorm(xcr)
-     xcr.dens <- dnorm(xcr)    
+    kriging.mean <- predx$mean
+    if(!minimization) kriging.mean <- -kriging.mean
+    kriging.sd <- predx$sd
+    v <- predx$Tinv.c
+    c <- predx$c
+    
+    xcr <- (m - kriging.mean)/kriging.sd
+    xcr.prob <- pnorm(xcr)
+    xcr.dens <- dnorm(xcr)    
   } else
   {  # If uploaded through "envir", no prediction computation is necessary 
-     toget <- matrix(c("xcr", "xcr.prob", "xcr.dens", "kriging.sd", "c", "Tinv.c"), 1, 6)
-     apply(toget, 2, get, envir=envir)
-     xcr        <- envir$xcr
-     xcr.prob   <- envir$xcr.prob
-     xcr.dens   <- envir$xcr.dens
-     kriging.sd <- envir$kriging.sd
-     c          <- envir$c
-     v          <- envir$Tinv.c
+    toget <- matrix(c("xcr", "xcr.prob", "xcr.dens", "kriging.sd", "c", "Tinv.c"), 1, 6)
+    apply(toget, 2, get, envir=envir)
+    xcr        <- envir$xcr
+    xcr.prob   <- envir$xcr.prob
+    xcr.dens   <- envir$xcr.dens
+    kriging.sd <- envir$kriging.sd
+    c          <- envir$c
+    v          <- envir$Tinv.c
   }
 
   F.newdata <- model.matrix(model@trend.formula, data=newdata)
@@ -160,19 +161,26 @@ EI.grad <- function(x, model, plugin=NULL, type="UK", minimization = TRUE, envir
     W <- backsolve(t(T), dc, upper.tri=FALSE)
     kriging.mean.grad <- t(W)%*%z + t(model@trend.coef%*%f.deltax)
     if (!minimization) kriging.mean.grad <- -kriging.mean.grad
-    if (type=="UK")
-    { tuuinv <- solve(t(u)%*%u)
-      kriging.sd2.grad <-  t( -2*t(v)%*%W +
-                            2*(F.newdata - t(v)%*%u )%*% tuuinv %*%
-                            (f.deltax - t(t(W)%*%u) ))
-    } else
-    { kriging.sd2.grad <-  t( -2*t(v)%*%W) }
     
-    kriging.sd.grad <- kriging.sd2.grad / (2*kriging.sd)
-
-    # Compute gradient of EI
-    ei.grad <- - kriging.mean.grad * xcr.prob + kriging.sd.grad * xcr.dens
+    if (proxy) {
+      ei.grad <- - kriging.mean.grad
+    } else {
+      
+      if (type=="UK")
+      { tuuinv <- solve(t(u)%*%u)
+      kriging.sd2.grad <-  t( -2*t(v)%*%W +
+                                2*(F.newdata - t(v)%*%u )%*% tuuinv %*%
+                                (f.deltax - t(t(W)%*%u) ))
+      } else
+      { kriging.sd2.grad <-  t( -2*t(v)%*%W) }
+      
+      kriging.sd.grad <- kriging.sd2.grad / (2*kriging.sd)
+      
+      # Compute gradient of EI
+      ei.grad <- - kriging.mean.grad * xcr.prob + kriging.sd.grad * xcr.dens
+    }
   }
+
   ########################################################################################  
   return(ei.grad)
-}
\ No newline at end of file
+}
